diff src/globals.h @ 16608:0422b14bce58 v8.1.1307

patch 8.1.1307: cannot reconnect to the X server after it restarted commit https://github.com/vim/vim/commit/d4aa83af1d691fdabbc8e6aab36db2c96ea4d4b6 Author: Bram Moolenaar <Bram@vim.org> Date: Thu May 9 18:59:31 2019 +0200 patch 8.1.1307: cannot reconnect to the X server after it restarted Problem: Cannot reconnect to the X server after it restarted. Solution: Add the :xrestore command. (Adrian Kocis, closes https://github.com/vim/vim/issues/844)
author Bram Moolenaar <Bram@vim.org>
date Thu, 09 May 2019 19:00:08 +0200
parents 42910f306377
children eda4d65f232c
line wrap: on
line diff
--- a/src/globals.h
+++ b/src/globals.h
@@ -1279,9 +1279,14 @@ EXTERN linenr_T printer_page_num;
 #endif
 
 #ifdef FEAT_XCLIPBOARD
-EXTERN char	*xterm_display INIT(= NULL);	/* xterm display name; points
-						   into argv[] */
-EXTERN Display	*xterm_dpy INIT(= NULL);	/* xterm display pointer */
+// xterm display name
+EXTERN char	*xterm_display INIT(= NULL);
+
+// whether xterm_display was allocated, when FALSE it points into argv[]
+EXTERN int	xterm_display_allocated INIT(= FALSE);
+
+// xterm display pointer
+EXTERN Display	*xterm_dpy INIT(= NULL);
 #endif
 #if defined(FEAT_XCLIPBOARD) || defined(FEAT_GUI_X11)
 EXTERN XtAppContext app_context INIT(= (XtAppContext)NULL);